@@ -1,30 +1,29 @@
 """AwesomeVersion."""
-# pylint: disable=unused-argument
-import logging
-from typing import List, Optional, Union
+from types import TracebackType
+from typing import Any, List, Optional, Type, Union
 
 from .exceptions import AwesomeVersionCompare, AwesomeVersionStrategyException
 from .handlers import CompareHandlers
-from .match import (
+from .strategy import VERSION_STRATEGIES, AwesomeVersionStrategy
+from .utils.logger import LOGGER
+from .utils.regex import (
     RE_DIGIT,
     RE_MODIFIER,
     RE_SEMVER,
+    RE_SIMPLE,
     RE_VERSION,
-    is_simple,
-    version_strategy,
+    get_regex_match_group,
+    is_regex_matching,
 )
-from .strategy import AwesomeVersionStrategy
-
-_LOGGER: logging.Logger = logging.getLogger(__package__)
 
 
 class _AwesomeVersionBase(str):
     """Base class for AwesomeVersion to allow the usage of the default JSON encoder."""
 
-    def __init__(self, string):
+    def __init__(self, string: str):
         str.__init__(string)
 
-    def __new__(cls, version, _=None):
+    def __new__(cls, version: str, _: Optional[Any] = None) -> "_AwesomeVersionBase":
         """Create a new AwesomeVersion object."""
 
         return super().__new__(cls, version)
@@ -43,6 +42,8 @@ class AwesomeVersion(_AwesomeVersionBase):
         AwesomeVersionStrategyException will be raised
     """
 
+    _version: str = ""
+
     def __init__(
         self,
         version: Union[str, float, int, "AwesomeVersion"],
@@ -74,7 +75,12 @@ class AwesomeVersion(_AwesomeVersionBase):
     def __enter__(self) -> "AwesomeVersion":
         return self
 
-    def __exit__(self, *exc_info) -> None:
+    def __exit__(
+        self,
+        exctype: Optional[Type[BaseException]],
+        excinst: Optional[BaseException],
+        exctb: Optional[TracebackType],
+    ) -> bool:
         pass
 
     def __repr__(self) -> str:
@@ -83,7 +89,7 @@ class AwesomeVersion(_AwesomeVersionBase):
     def __str__(self) -> str:
         return str(self._version)
 
-    def __eq__(self, compareto: Union[str, float, int, "AwesomeVersion"]) -> bool:
+    def __eq__(self, compareto: Union[str, float, int, object]) -> bool:
         """Check if equals to."""
         if isinstance(compareto, (str, float, int)):
             compareto = AwesomeVersion(compareto)
@@ -91,7 +97,7 @@ class AwesomeVersion(_AwesomeVersionBase):
             raise AwesomeVersionCompare("Not a valid AwesomeVersion object")
         return self.string == compareto.string
 
-    def __lt__(self, compareto: Union[str, float, int, "AwesomeVersion"]) -> bool:
+    def __lt__(self, compareto: Union[str, float, int, object]) -> bool:
         """Check if less than."""
         if isinstance(compareto, (str, float, int)):
             compareto = AwesomeVersion(compareto)
@@ -105,7 +111,7 @@ class AwesomeVersion(_AwesomeVersionBase):
             )
         return CompareHandlers(compareto, self).check()
 
-    def __gt__(self, compareto: Union[str, float, int, "AwesomeVersion"]) -> bool:
+    def __gt__(self, compareto: Union[str, float, int, object]) -> bool:
         """Check if greater than."""
         if isinstance(compareto, (str, float, int)):
             compareto = AwesomeVersion(compareto)
@@ -119,19 +125,21 @@ class AwesomeVersion(_AwesomeVersionBase):
             )
         return CompareHandlers(self, compareto).check()
 
-    def __ne__(self, compareto: "AwesomeVersion") -> bool:
+    def __ne__(self, compareto: object) -> bool:
         return not self.__eq__(compareto)
 
-    def __le__(self, compareto: "AwesomeVersion") -> bool:
+    def __le__(self, compareto: object) -> bool:
         return self.__eq__(compareto) or self.__lt__(compareto)
 
-    def __ge__(self, compareto: "AwesomeVersion") -> bool:
+    def __ge__(self, compareto: object) -> bool:
         return self.__eq__(compareto) or self.__gt__(compareto)
 
     def section(self, idx: int) -> int:
         """Return the value of the specified section of the version."""
         if self.sections >= (idx + 1):
-            return int(RE_DIGIT.match(self.string.split(".")[idx]).group(1))
+            match = get_regex_match_group(RE_DIGIT, (self.string.split(".")[idx]), 1)
+            if match:
+                return int(match)
         return 0
 
     @staticmethod
@@ -140,7 +148,7 @@ class AwesomeVersion(_AwesomeVersionBase):
         strategy: Union[AwesomeVersionStrategy, List[AwesomeVersionStrategy]],
     ) -> "AwesomeVersion":
         """Return a AwesomeVersion object, or raise on creation."""
-        _LOGGER.warning(
+        LOGGER.warning(
             "Using AwesomeVersion.ensure_strategy(version, strategy) is deprecated, "
             "use AwesomeVersion(version, strategy) instead"
         )
@@ -151,13 +159,13 @@ class AwesomeVersion(_AwesomeVersionBase):
         """Return a string representaion of the version."""
         if self._version.endswith("."):
             self._version = self._version[:-1]
-        version = RE_VERSION.match(str(self._version)).group(2)
-        return version
+        version = get_regex_match_group(RE_VERSION, str(self._version), 2)
+        return version or self._version
 
     @property
     def prefix(self) -> Optional[str]:
         """Return the version prefix if any"""
-        return RE_VERSION.match(str(self._version)).group(1)
+        return get_regex_match_group(RE_VERSION, str(self._version), 1)
 
     @property
     def alpha(self) -> bool:
@@ -208,33 +216,41 @@ class AwesomeVersion(_AwesomeVersionBase):
         return AwesomeVersion(self.section(2))
 
     @property
-    def modifier(self) -> str:
+    def modifier(self) -> Optional[str]:
         """Return the modifier of the version if any."""
-        if self.strategy == AwesomeVersionStrategy.SEMVER:
-            match = RE_MODIFIER.match(RE_SEMVER.match(self.string).group(4) or "")
-        elif self.strategy == AwesomeVersionStrategy.SPECIALCONTAINER:
+        if self.strategy == AwesomeVersionStrategy.SPECIALCONTAINER:
             return None
+
+        if self.strategy == AwesomeVersionStrategy.SEMVER:
+            modifier_string = get_regex_match_group(RE_SEMVER, str(self.string), 4)
         else:
-            match = RE_MODIFIER.match(self.string.split(".")[-1])
-        return match.group(2) if match else None
+            modifier_string = self.string.split(".")[-1]
+
+        return get_regex_match_group(RE_MODIFIER, modifier_string, 2)
 
     @property
-    def modifier_type(self) -> str:
+    def modifier_type(self) -> Optional[str]:
         """Return the modifier type of the version if any."""
-        if self.strategy == AwesomeVersionStrategy.SEMVER:
-            match = RE_MODIFIER.match(RE_SEMVER.match(self.string).group(4) or "")
-        elif self.strategy == AwesomeVersionStrategy.SPECIALCONTAINER:
+        if self.strategy == AwesomeVersionStrategy.SPECIALCONTAINER:
             return None
+
+        if self.strategy == AwesomeVersionStrategy.SEMVER:
+            modifier_string = get_regex_match_group(RE_SEMVER, str(self.string), 4)
         else:
-            match = RE_MODIFIER.match(self.string.split(".")[-1])
-        return match.group(3) if match else None
+            modifier_string = self.string.split(".")[-1]
+
+        return get_regex_match_group(RE_MODIFIER, modifier_string, 3)
 
     @property
     def strategy(self) -> AwesomeVersionStrategy:
         """Return the version strategy."""
-        return version_strategy(self.string)
+        for pattern, strategy in VERSION_STRATEGIES:
+            if is_regex_matching(pattern, self.string):
+                return strategy
+
+        return AwesomeVersionStrategy.UNKNOWN
 
     @property
     def simple(self) -> bool:
         """Return True if the version string is simple."""
-        return is_simple(self.string)
+        return is_regex_matching(RE_SIMPLE, self.string)
